# OptraBot
OptraBot is a Options Trading Bot which can be used to run fully automated options trading strategies using your Interactive Brokers trading account.

Have a look on the **[Roadmap](https://app.loopedin.io/optrabot/roadmap)** and discover what we're currently working on and whats coming next.

Run through the **[Changelog](https://app.loopedin.io/optrabot/#/updates)** and find out about the most recent updates of the software.

## System requirements
Microsoft Windows, MacOS or Linux operating system

Python 3.10 or newer

Interactive Brokers Trader Workstation or IB Gateway

## Disclaimer
Be aware that you're using this software at your own risk. The author is not liable for any losses occuring with using this software.
